# Customize wxWidgets path and check the presence of levmar library
# before running GNU Make. It supports the next platforms:
# * MINGW for win32 and win64
# * Linux ang GCC
#
# Required packages in Ubuntu Linux:
# libwxgtk-media3.0

# Some platform-independent keys
LMLIB=-L. -llevmar -llua5.3
# Debug settings
#OBJKEYS=-O2 -g  -std=gnu++0x -Wall
#LINKKEYS=-O2 -g  -std=gnu++0x -Wall
# Release settings
OBJKEYS=-s -O2 -ffunction-sections -fdata-sections -std=gnu++0x -Wall
LINKKEYS=-s -O2 -Wl,--gc-sections
# For gprof
#OBJKEYS=-pg
#LINKKEYS=-pg
# Some platform-dependent keys
PLATFORM=$(shell uname)
ifeq ($(findstring MINGW32_NT, $(PLATFORM)), MINGW32_NT)
LIBINCLUDE = -IC:/cprog/cp/lua -IC:/cprog/levmar-2.6
WXINCLUDE = -IC:/cprog/wxwidgets/include -IC:/cprog/wxwidgets/lib/wx/include/msw-unicode-3.0 $(LIBINCLUDE)
WXLIB_CONSOLE=-Lc:/cprog/wxwidgets/lib -mthreads -lwxcode_mswu_freechart-3.0 -lwx_mswu_adv-3.0  -lwx_mswu_core-3.0  -lwx_baseu-3.0 -lwxtiff-3.0 -lwxjpeg-3.0 -lwxpng-3.0   -lwxzlib-3.0 -lwxregexu-3.0 -lwxexpat-3.0 -mthreads   -lrpcrt4 -loleaut32 -lole32 -luuid -lwinspool -lwinmm -lshell32 -lcomctl32 -lcomdlg32 -ladvapi32 -lwsock32 -lgdi32  -lrpcrt4 -loleaut32 -lole32 -luuid -lwinspool -lwinmm -lshell32 -lcomctl32 -lcomdlg32 -ladvapi32 -lwsock32 -lgdi32
WXLIB=$(WXLIB_CONSOLE) -mwindows
EXE=.exe
RESOBJ=sample_rc.o
else
WXINCLUDE=$(shell wx-config --cxxflags)
WXLIB_CONSOLE=$(shell wx-config --libs)
WXLIB=$(shell wx-config --libs)
EXE=
RESOBJ=
endif
# Targets description
main: cpfit$(EXE) cpfit_cmd$(EXE) test_datafit$(EXE) dfunc3_test$(EXE)
test_datafit$(EXE): test_datafit.o datafit.o datafit_eterms.o tdmodel.o dfunc3.o
	g++ test_datafit.o datafit.o datafit_eterms.o dfunc3.o tdmodel.o $(LMLIB) $(LIBINCLUDE) -o test_datafit$(EXE) $(LINKKEYS)
test_lua$(EXE): test_lua.o datafit.o datafit_eterms.o tdmodel.o 
	g++ test_lua.o datafit.o datafit_eterms.o dfunc3.o -o test_lua$(EXE) $(LMLIB) $(LIBINCLUDE)
test_lua_o: test_lua.cpp
	g++ test_lua.cpp -c -o test_lua.o -L. -llua53 $(LIBINCLUDE)
cpfit$(EXE): cp.o $(RESOBJ) graph.o datafit.o datafit_eterms.o paramedit.o plotcanvas.o tdmodel.o tdtable.o xydatafile.o xyplots.o misc.o dfunc3.o customgrids.o
	g++ cp.o graph.o $(RESOBJ) customgrids.o datafit.o datafit_eterms.o paramedit.o plotcanvas.o tdmodel.o tdtable.o xydatafile.o xyplots.o misc.o dfunc3.o -o cpfit$(EXE) $(WXLIB) $(LINKKEYS) $(LMLIB) -Wl,-Map=cpfit.map
cpfit_cmd$(EXE): cpfit_cmd.o xydatafile_con.o datafit.o datafit_eterms.o dfunc3.o tdmodel.o
	g++ cpfit_cmd.o xydatafile_con.o datafit.o datafit_eterms.o dfunc3.o tdmodel.o -o cpfit_cmd$(EXE) $(WXLIB_CONSOLE) $(LINKKEYS) $(LMLIB) $(WXLIB_CONSOLE)  $(LIBINCLUDE)
dfunc3_test$(EXE): dfunc3_test.o dfunc3.o
	g++ dfunc3_test.o dfunc3.o -o dfunc3_test$(EXE)
dfunc3_test.o: dfunc3_test.cpp dfunc3.h
	g++ dfunc3_test.cpp -c -o dfunc3_test.o $(OBJKEYS)
dfunc3.o: dfunc3.cpp dfunc3.h
	g++ dfunc3.cpp -c -o dfunc3.o $(OBJKEYS)
misc.o: misc.cpp *.h
	g++ misc.cpp -c -o misc.o $(WXINCLUDE) $(OBJKEYS)
cp.o: cp.cpp *.h
	g++ cp.cpp -c -o cp.o $(WXINCLUDE) $(OBJKEYS)
cpfit_cmd.o: cpfit_cmd.cpp *.h
	g++ cpfit_cmd.cpp -c -o cpfit_cmd.o $(WXINCLUDE) $(OBJKEYS)
test_datafit.o: test_datafit.cpp *.h
	g++ test_datafit.cpp -c -o test_datafit.o $(OBJKEYS) $(LIBINCLUDE)
customgrids.o: customgrids.cpp *.h
	g++ customgrids.cpp -c -o customgrids.o $(WXINCLUDE) $(OBJKEYS)
graph.o: graph.cpp *.h
	g++ graph.cpp -c -o graph.o $(WXINCLUDE) $(OBJKEYS)
datafit.o: datafit.cpp *.h
	g++ datafit.cpp -c -o datafit.o $(WXINCLUDE) $(OBJKEYS)
datafit_eterms.o: datafit_eterms.cpp *.h
	g++ datafit_eterms.cpp -c -o datafit_eterms.o $(WXINCLUDE) $(OBJKEYS)
paramedit.o: paramedit.cpp *.h
	g++ paramedit.cpp -c -o paramedit.o $(WXINCLUDE) $(OBJKEYS)
plotcanvas.o: plotcanvas.cpp *.h
	g++ plotcanvas.cpp -c -o plotcanvas.o $(WXINCLUDE) $(OBJKEYS)
tdmodel.o: tdmodel.cpp *.h
	g++ tdmodel.cpp -c -o tdmodel.o $(WXINCLUDE) $(OBJKEYS)
tdtable.o: tdtable.cpp *.h
	g++ tdtable.cpp -c -o tdtable.o $(WXINCLUDE) $(OBJKEYS)
xyplots.o: xyplots.cpp *.h
	g++ xyplots.cpp -c -o xyplots.o $(WXINCLUDE) $(OBJKEYS)
xydatafile.o: xydatafile.cpp *.h
	g++ xydatafile.cpp -c -o xydatafile.o $(WXINCLUDE) $(OBJKEYS)
xydatafile_con.o: xydatafile.cpp *.h
	g++ xydatafile.cpp -c -o xydatafile_con.o $(WXINCLUDE) $(OBJKEYS) -DXYDATAFILE_CONSOLE
sample_rc.o: sample.rc cpfit.ico term_default.bmp term_twopeaks.bmp *.h
ifeq ($(findstring MINGW32_NT, $(PLATFORM)), MINGW32_NT)
	windres -isample.rc -osample_rc.o  --define __WXMSW__  -I. $(WXINCLUDE)
endif
clean:
	rm *.o
	rm cpfit.exe
	rm cpfit_cmd.exe
	