/**
 * \file 
 * \brief Widget that shows and allows to edit parameters of thermodynamic model
 * (&alpha; and &theta; in Einstein functions part and a in the polynomial part.
 *
 * \author Alexey L. Voskov (alvoskov@gmail.com)
 * \copyright (C) 2016-2020 Alexey L. Voskov
 *
 * Laboratory of Chemical Thermodynamics, Department of Chemistry,
 *
 * Lomonosov Moscow State University, Moscow, Russia, 119991
 *
 * This file is the part of the CpFit program
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/);
 */

#ifndef __PARAMEDIT_H
#define __PARAMEDIT_H
#include <vector>
#include <functional>

class ParametersWindow : public wxPanel
{
public:
	ParametersWindow(wxWindow *parent, std::function <void()> cbfEvalParam);
	double GetFixedNatoms(bool *isOk = NULL);
	void ResetParameters();
	std::vector <double> ReadPolyCoeff();
	std::vector <double> ReadPolyDegree();
	std::vector <double> ReadAlpha();
	std::vector <double> ReadTheta();
	bool WriteAlpha(std::vector <double> alpha);
	bool WriteTheta(std::vector <double> theta);
	bool WritePolyCoeff(std::vector <double> coeff);
	bool WritePolyDegree(std::vector <double> degree);

private:
	wxDECLARE_EVENT_TABLE();
	// Event handlers
	void OnResetPar(wxCommandEvent &event);
	void OnEvalPar(wxCommandEvent &event);
	void OnTextEvent(wxCommandEvent& event);
	void OnCmbParNum(wxCommandEvent &event);
	void OnCmbParNumPoly(wxCommandEvent &event);
	void OnChkFixedNatoms(wxCommandEvent &event);
	void OnParamGridCellChanging(wxGridEvent& event);
	void OnSize(wxSizeEvent &event);
	// Another functions
	void ResizeParamGrid(int numOfRows);
	void ResizePolyParamGrid(int numOfRows);


	std::function <void()> cbfEvalParam;
	wxStaticBox *box;
	wxGrid *grPar; ///< Einstein functions parameters
	wxGrid *grParPoly; ///< Polynomial parameters
	// Buttons
	wxButton *btnCalc;
	wxButton *btnReset;
	// Controls for fixed/varied Nat
	wxCheckBox *chkFixedNatoms;
	wxTextCtrl *txtFixedNatoms;
	wxString strFixedNatomsOld;
	// Another controls
	wxComboBox *cmbParNum;
	wxComboBox *cmbParNumPoly;
	wxString strNotNumeric;
	wxStaticText *lblParNum;
	wxStaticText *lblParNumPoly;
	// Some choices for comboboxes
	static const wxString polyDegreeChoices[];
	static const wxString parNumChoices[];

};

#endif