/**
 * \file
 * \brief Implementation of CpFit file formats (with experimental data) 
 * \author Alexey L. Voskov (alvoskov@gmail.com)
 * \copyright (C) 2016-2020 Alexey L. Voskov
 *
 * Laboratory of Chemical Thermodynamics, Department of Chemistry,
 *
 * Lomonosov Moscow State University, Moscow, Russia, 119991
 *
 * This file is the part of the CpFit program
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/);
 */

#ifndef __XYDATAFILE_H
#define __XYDATAFILE_H
/**
 * \brief  Loads/saves data from disk
 */
class XYDataFile : public LSQContext
{
public:
	XYDataFile();
	bool LoadFile(wxString &fileName, int fmt = 0);
	bool SaveFile(wxString &fileName, int fmt = 0);
	void Reset();
	wxString GetFileName();
	std::vector <wxString> GetFileInfo();
	bool SetFileInfo(std::vector <wxString> fileInfo);

	bool writeToStdio;
	
	static const int FMT_BELOV = 0;
private:
	int ParsePoint(wxString &str, Point &point);
	std::vector <wxString> fileInfo;
	wxString fileName;

	static int MessageBoxStub(const wxString & message, const wxString & caption, int style);
};
#endif
